@@ -24,7 +24,7 @@ double pmf_bpois(double x, double y, double a, double b, double c) {
     return NAN;
   }
   
-  if (!isInteger(x))
+  if (!isInteger(x) || x < 0.0)
     return 0.0;
   
   if (floor(y) != y) {
@@ -34,6 +34,9 @@ double pmf_bpois(double x, double y, double a, double b, double c) {
     return 0.0;
   }
   
+  if (y < 0.0)
+    return 0.0;
+  
   double tmp = exp(-(a+b+c)); 
   tmp *= (pow(a, x) / factorial(x)) * (pow(b, y) / factorial(y));
   double xy = 0.0;
