@@ -1,4 +1,5 @@
 #include <Rcpp.h>
+#include "shared.h"
 
 using std::pow;
 using std::sqrt;
@@ -172,7 +173,7 @@ NumericVector cpp_rfrechet(
   NumericVector x(n);
 
   for (int i = 0; i < n; i++) {
-    u = R::runif(0.0, 1.0);
+    u = rng_unif();
     x[i] = invcdf_frechet(u, lambda[i % nl], mu[i % nm], sigma[i % ns]);
   }
 
