@@ -1,4 +1,5 @@
 #include <Rcpp.h>
+#include "shared.h"
 
 using std::pow;
 using std::sqrt;
@@ -194,7 +195,7 @@ NumericVector cpp_rgpd(
   NumericVector x(n);
 
   for (int i = 0; i < n; i++) {
-    u = R::runif(0.0, 1.0);
+    u = rng_unif();
     x[i] = invcdf_gpd(u, mu[i % nm], sigma[i % ns], xi[i % nx]);
   }
 
