@@ -185,7 +185,7 @@ NumericVector cpp_rhuber(
   NumericVector x(n);
   
   for (int i = 0; i < n; i++) {
-    u = R::runif(0.0, 1.0);
+    u = rng_unif();
     x[i] = invcdf_huber(u, mu[i % nm], sigma[i % ns], epsilon[i % ne]);
   }
   
